@@ -1,9 +1,12 @@
 #define QT_FEATURE_wayland_server 1
-#define QT_FEATURE_drm_egl_server 1
-#define QT_FEATURE_libhybris_egl_server -1
 #define QT_FEATURE_wayland_brcm -1
 #define QT_FEATURE_wayland_datadevice 1
+#define QT_FEATURE_wayland_dmabuf_client_buffer 1
+#define QT_FEATURE_wayland_dmabuf_server_buffer 1
+#define QT_FEATURE_wayland_drm_egl_server_buffer 1
 #define QT_FEATURE_wayland_egl 1
 #define QT_FEATURE_wayland_layer_integration_vsp2 -1
+#define QT_FEATURE_wayland_libhybris_egl_server_buffer -1
+#define QT_FEATURE_wayland_shm_emulation_server_buffer 1
 #define QT_FEATURE_xcomposite_egl 1
 #define QT_FEATURE_xcomposite_glx 1
